@@ -5,10 +5,10 @@
 
 #include <QObject>
 
-class EiKeyset: public PIRKeysetMetaData
+class EiTV1: public PIRKeysetMetaData
 {
 public:
-  EiKeyset(
+  EiTV1(
     QObject *guiObject,
     unsigned int index);
 };
