@@ -15,7 +15,7 @@ MagnavoxDVD1::MagnavoxDVD1(
 
   threadableProtocol = new RC6Protocol(guiObject, index, 0x04);
 
-  addKey("power", Power_Key, 0x0C, 8);
+  addKey("0", Zero_Key, 0x00, 8);
   addKey("1", One_Key, 0x01, 8);
   addKey("2", Two_Key, 0x02, 8);
   addKey("3", Three_Key, 0x03, 8);
@@ -25,29 +25,29 @@ MagnavoxDVD1::MagnavoxDVD1(
   addKey("7", Seven_Key, 0x07, 8);
   addKey("8", Eight_Key, 0x08, 8);
   addKey("9", Nine_Key, 0x09, 8);
-  addKey("0", Zero_Key, 0x00, 8);
-  addKey("title", DiscTitle_Key, 0x83, 8);
+  addKey("power", Power_Key, 0x0C, 8);
+  addKey("mute", Mute_Key, 0x0D, 8);
   addKey("display", Info_Key, 0x0F, 8);
+  addKey("repeat", Repeat_Key, 0x1D, 8);
+  addKey(">>", FastForward_Key, 0x20, 8);
+  addKey("<<", Rewind_Key, 0x21, 8);
+  addKey("play", Play_Key, 0x2C, 8);
+  addKey("pause", Pause_Key, 0x30, 8);
+  addKey("stop", Stop_Key, 0x31, 8);
+  addKey("a-b", RepeatAB_Key, 0x3B, 8);
+  addKey("subtitle", Captions_Key, 0x4B, 8);
+  addKey("audio", Audio_Key, 0x4E, 8);
   addKey("disc_Menu", DiscMenu_Key, 0x54, 8);
-  addKey("system_menu", Menu_Key, 0x82, 8);
   addKey("^", Up_Key, 0x58, 8);
   addKey("<", Left_Key, 0x5A, 8);
   addKey(">", Right_Key, 0x5B, 8);
   addKey("v", Down_Key, 0x5C, 8);
   addKey("ok", Select_Key, 0x5D, 8);
-  addKey("<<", Rewind_Key, 0x21, 8);
-  addKey(">>", FastForward_Key, 0x20, 8);
-  addKey("stop", Stop_Key, 0x31, 8);
-  addKey("play", Play_Key, 0x2C, 8);
-  addKey("pause", Pause_Key, 0x30, 8);
-  addKey("subtitle", Captions_Key, 0x4B, 8);
-  addKey("angle", Unmapped_Key, 0x85, 8);
-  addKey("zoom", Unmapped_Key, 0xF7, 8);
-  addKey("audio", Unmapped_Key, 0x4E, 8);
-  addKey("repeat", Unmapped_Key, 0x1D, 8);
-  addKey("a-b", Unmapped_Key, 0x3B, 8);
+  addKey("system_menu", Menu_Key, 0x82, 8);
+  addKey("title", DiscTitle_Key, 0x83, 8);
+  addKey("angle", Angle_Key, 0x85, 8);
   addKey("preview", Unmapped_Key, 0xD5, 8);
-  addKey("mute", Mute_Key, 0x0D, 8);
+  addKey("zoom", Zoom_Key, 0xF7, 8);
 }
 
 
@@ -104,11 +104,11 @@ MagnavoxVCR1::MagnavoxVCR1(
   addKey("VcrChUp", Unmapped_Key, 0x1160, 13);
   addKey("VcrChDn", Unmapped_Key, 0x1161, 13);
   addKey("Menu", Menu_Key, 0x115D, 13);
-  addKey("Slow", Unmapped_Key, 0x1168, 13);
+  addKey("Slow", Slow_Key, 0x1168, 13);
   addKey("Status", Info_Key, 0x114F, 13);
   addKey("Clear", Clear_Key, 0x1171, 13);
-  addKey("VarSlowUp", Unmapped_Key, 0x1166, 13);
-  addKey("VarSlowDn", Unmapped_Key, 0x1165, 13);
+  addKey("VarSlowUp", SlowPlus_Key, 0x1166, 13);
+  addKey("VarSlowDn", SlowMinus_Key, 0x1165, 13);
   addKey("Qtr", Unmapped_Key, 0x1167, 13);
   addKey("TrackUp", TrackingPlus_Key, 0x014D, 13);
   addKey("TrackDn", TrackingMinus_Key, 0x014E, 13);
@@ -135,7 +135,8 @@ MagnavoxConverterBox1::MagnavoxConverterBox1(
     index,
     894, 795,
     894, 2537,
-    33751, false);
+    33751, false,
+    LIRC_NEC);
 
   threadableProtocol = np;
 
@@ -181,15 +182,7 @@ MagnavoxTV1::MagnavoxTV1(
 {
   threadableProtocol = new RC5Protocol(guiObject, index, 0x40);
 
-  addKey("Power", Power_Key, 0x0C, 6);
-  addKey("Reset", Reset_Key, 0x0E, 6);
-  addKey("Sleep", Sleep_Key, 0x26, 6);
-  addKey("Mute", Mute_Key, 0x0D, 6);
-  addKey("VolUp", VolumeUp_Key, 0x10, 6);
-  addKey("VolDown", VolumeDown_Key, 0x11, 6);
-  addKey("ChUp", ChannelUp_Key, 0x20, 6);
-  addKey("ChDown", ChannelDown_Key, 0x21, 6);
-  addKey("PrevCh", PrevChannel_Key, 0x21, 6);
+  addKey("Zero", Zero_Key, 0x00, 6);
   addKey("One", One_Key, 0x01, 6);
   addKey("Two", Two_Key, 0x02, 6);
   addKey("Three", Three_Key, 0x03, 6);
@@ -199,14 +192,22 @@ MagnavoxTV1::MagnavoxTV1(
   addKey("Seven", Seven_Key, 0x07, 6);
   addKey("Eight", Eight_Key, 0x08, 6);
   addKey("Nine", Nine_Key, 0x09, 6);
-  addKey("Zero", Zero_Key, 0x00, 6);
-  addKey("Display", Info_Key, 0x2E, 6);
-  addKey("Plus", Right_Key, 0x2B, 6);
-  addKey("Minus", Left_Key, 0x2C, 6);
+  addKey("Power", Power_Key, 0x0C, 6);
+  addKey("Mute", Mute_Key, 0x0D, 6);
+  addKey("Reset", Reset_Key, 0x0E, 6);
   addKey("Status", Unmapped_Key, 0x0F, 6);
+  addKey("VolUp", VolumeUp_Key, 0x10, 6);
+  addKey("VolDown", VolumeDown_Key, 0x11, 6);
   addKey("Play", Play_Key, 0x1C, 6);
   addKey("Stop", Stop_Key, 0x1D, 6);
+  addKey("ChUp", ChannelUp_Key, 0x20, 6);
+  addKey("ChDown", ChannelDown_Key, 0x21, 6);
+  addKey("PrevCh", PrevChannel_Key, 0x22, 6);
+  addKey("Sleep", Sleep_Key, 0x26, 6);
+  addKey("Plus", Right_Key, 0x2B, 6);
   addKey("FF", FastForward_Key, 0x2B, 6);
+  addKey("Minus", Left_Key, 0x2C, 6);
   addKey("Rev", Rewind_Key, 0x2C, 6);
+  addKey("Display", Info_Key, 0x2E, 6);
   addKey("Pause", Pause_Key, 0x3B, 6);
 }
