@@ -26,6 +26,8 @@ enum PIRKeyName{
   DoubleDigit_Key,
   // Power control:
   Power_Key,
+  PowerOn_Key,
+  PowerOff_Key,
   // Volume control:
   VolumeUp_Key,
   VolumeDown_Key,
@@ -40,6 +42,9 @@ enum PIRKeyName{
   Pause_Key,
   Stop_Key,
   Record_Key,
+  RecordPause_Key,
+  RecordStop_Key,
+  RecordMute_Key,
   FastForward_Key,
   Rewind_Key,
   Next_Key,
@@ -51,6 +56,12 @@ enum PIRKeyName{
   Eject_Key,
   Random_Key,
   Repeat_Key,
+  RepeatAB_Key,
+  Slow_Key,
+  SlowPlus_Key,
+  SlowMinus_Key,
+  Timer_Key,
+  Clock_Key,
   // Menu control:
   Menu_Key,
   Up_Key,
@@ -59,11 +70,27 @@ enum PIRKeyName{
   Right_Key,
   Select_Key,
   Exit_Key,
+  PageUp_Key,
+  PageDown_Key,
   // Color buttons:
   Red_Key,
   Green_Key,
   Yellow_Key,
   Blue_Key,
+  // Teletext buttons:
+  Teletext_Key,
+  TeletextReveal_Key,
+  TeletextHold_Key,
+  TeletextSize_Key,
+  TeletextSelect_Key,
+  TeletextTime_Key,
+  TeletextAndTV_Key,
+  TeletextDown_Key,
+  TeletextUp_Key,
+  TeletextBackgroundTV_Key,
+  TeletextStore_Key,
+  TeletextIndex_Key,
+  TeletextOff_Key,
   // Picture-in-picture stuff:
   PIP_Key,
   PIPSwap_Key,
@@ -72,10 +99,13 @@ enum PIRKeyName{
   PIPChannelUp_Key,
   PIPChannelDown_Key,
   PIPPause_Key,
+  PIPSize_Key,
+  PIPScan_Key,
   // DVD / Blue-ray / etc. keys:
   DiscTitle_Key,
   DiscMenu_Key,
   DiscSelect_Key,
+  Angle_Key,
   // VHS / Beta / etc. keys:
   VHSSpeed_Key,
   TrackingPlus_Key,
@@ -88,15 +118,16 @@ enum PIRKeyName{
   Sleep_Key,
   PictureMode_Key, // "PMODE"
   SoundMode_Key,
-  Clock_Key,
-  Timer_Key,
   Reset_Key,
   Program_Key,
   Surround_Key,
   AspectRatio_Key,
-  Language_Key,
+  Audio_Key,
   Favorites_Key,
-  Scan_Key
+  Scan_Key,
+  Zoom_Key,
+  LiveTV_Key,
+  TunerBand_Key
 };
 
 #endif // PIRKEYNAMES_H
