@@ -16,14 +16,7 @@ public:
   RC6Protocol(
     QObject *guiObject,
     unsigned int index,
-    unsigned int bPulse,
-    unsigned int bSpace,
-    unsigned int gSpace,
-    bool iclFlag);
-
-  void setHeaderPair(
-    unsigned int pulse,
-    unsigned int space);
+    unsigned int eightBitControl);
 
 public slots:
   void startSendingCommand(
@@ -31,12 +24,7 @@ public slots:
     PIRKeyName command);
 
 protected:
-  unsigned int biphasePulse;
-  unsigned int biphaseSpace;
-
-  unsigned int headerPulse;
-  unsigned int headerSpace;
-  bool hasHeaderPair;
+  unsigned int biphaseUnit;
 
 private:
   int pushBits(
